"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useTeachers } from "@/lib/hooks/useTeachers";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { Button } from "@/components/ui/button";
import { Search, UserPlus } from "lucide-react";
import { DialogHeader, Dialog, DialogContent, DialogDescription, DialogTitle } from "@/components/ui/dialog";
import { Teacher } from "@/lib/types";
import { TeacherForm } from "@/components/teachers/TeacherForm";
import { TeacherList } from "@/components/teachers/TeacherList";

export default function TeachersPage() {
  const router = useRouter();
  const { user, loading: authLoading } = useAuth();
  const { teachers, loading: teachersLoading } = useTeachers();
  const [isAddDialogOpen, setIsAddDialogOpen] = useState(false);
  const [isEditDialogOpen, setIsEditDialogOpen] = useState(false);
  const [selectedTeacher, setSelectedTeacher] = useState<Teacher | null>(null);

  // Handle viewing a teacher
  const handleViewTeacher = (teacher: Teacher) => {
    setSelectedTeacher(teacher);
    router.push(`/teachers/${teacher.id}`);
  };

  // Handle editing a teacher
  const handleEditTeacher = (teacher: Teacher) => {
    setSelectedTeacher(teacher);
    setIsEditDialogOpen(true);
  };
  
  // Redirect if not admin
  if (!authLoading && (!user || user.role !== "admin")) {
    router.push("/dashboard");
    return null;
  }

  const isLoading = authLoading || teachersLoading;

  if (isLoading) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

   return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex justify-between items-center">
          <div>
            <h1 className="text-3xl font-bold tracking-tight">Teachers</h1>
            <p className="text-muted-foreground">
              Manage teacher information and assignments
            </p>
          </div>
          <Button onClick={() => setIsAddDialogOpen(true)}>
            <UserPlus className="h-4 w-4 mr-2" />
            Add Teacher
          </Button>
        </div>

        <TeacherList onView={handleViewTeacher} onEdit={handleEditTeacher} />

        {/* Add Teacher Dialog */}
        <Dialog open={isAddDialogOpen} onOpenChange={setIsAddDialogOpen}>
          <DialogContent className="max-w-4xl">
            <DialogHeader>
              <DialogTitle>Add New Teacher</DialogTitle>
              <DialogDescription>
                Create a new teacher record in the system
              </DialogDescription>
            </DialogHeader>
            <TeacherForm 
              // classes={classes}s
              onSuccess={() => setIsAddDialogOpen(false)}
            />
          </DialogContent>
        </Dialog>

        {/* Edit Student Dialog */}
        <Dialog open={isEditDialogOpen} onOpenChange={setIsEditDialogOpen}>
          <DialogContent className="max-w-4xl">
            <DialogHeader>
              <DialogTitle>Edit Teacher</DialogTitle>
              <DialogDescription>
                Update the teacher's information
              </DialogDescription>
            </DialogHeader>
            {selectedTeacher && (
              <TeacherForm 
                teacher={selectedTeacher}
                // classes={classes}
                onSuccess={() => setIsEditDialogOpen(false)}
              />
            )}
          </DialogContent>
        </Dialog>
      </div>
    </DashboardLayout>
  );
}